@@ -6,25 +6,22 @@
 # -- Project information -----------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
 
-project = 'squidasm'
-copyright = '2023, QuTech'
-author = 'Axel Dahlberg, Michal van Hooft'
+project = "squidasm"
+copyright = "2023, QuTech"
+author = "Axel Dahlberg, Michal van Hooft"
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
 
-extensions = ['sphinx_rtd_theme',
-              "sphinx.ext.autodoc",
-              "sphinx_autodoc_typehints"
-              ]
+extensions = ["sphinx_rtd_theme", "sphinx.ext.autodoc", "sphinx_autodoc_typehints"]
 
 
-templates_path = ['_templates']
-exclude_patterns = ['.DS_Store']
+templates_path = ["_templates"]
+exclude_patterns = [".DS_Store"]
 
 
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
 html_theme = "sphinx_rtd_theme"
-html_static_path = ['_static']
+html_static_path = ["_static"]
